=== modified file 'commit.py'
--- commit.py	2007-10-02 23:08:12 +0000
+++ commit.py	2007-10-03 15:49:31 +0000
@@ -322,6 +322,9 @@
         self._files_box.show()
         self._left_pane_box.pack_start(self._files_box)
 
+        # Keep note that all strings stored in a ListStore must be UTF-8
+        # strings. GTK does not support directly setting and restoring Unicode
+        # objects.
         liststore = gtk.ListStore(
             gobject.TYPE_STRING,  # [0] file_id
             gobject.TYPE_STRING,  # [1] real path
@@ -495,6 +498,10 @@
             self._last_selected_file = self._files_store.get_path(selection)
 
     def _get_specific_files(self):
+        """Return the list of selected paths, and file info.
+
+        :return: ([unicode paths], [{utf-8 file info}]
+        """
         self._save_current_file_message()
         files = []
         records = iter(self._files_store)
@@ -503,9 +510,9 @@
 
         file_info = []
         for record in records:
-            if record[2]: # [2] checkbox
+            if record[2]:           # [2] checkbox
                 file_id = record[0] # [0] file_id
-                path = record[1] # [1] real path
+                path = record[1]    # [1] real path
                 file_message = record[5] # [5] commit message
                 files.append(path.decode('UTF-8'))
                 if file_message:
@@ -554,7 +561,7 @@
         rev_id = None
         revprops = {}
         if file_info:
-            revprops['file-info'] = bencode.bencode(file_info)
+            revprops['file-info'] = bencode.bencode(file_info).decode('UTF-8')
         try:
             rev_id = self._wt.commit(message,
                        allow_pointless=False,

=== modified file 'logview.py'
--- logview.py	2007-10-01 17:37:36 +0000
+++ logview.py	2007-10-03 15:49:31 +0000
@@ -101,7 +101,7 @@
 
         file_info = revision.properties.get('file-info', None)
         if file_info is not None:
-            file_info = bencode.bdecode(file_info)
+            file_info = bencode.bdecode(file_info.encode('UTF-8'))
 
         if file_info:
             if self._file_id is None:

=== modified file 'tests/test_commit.py'
--- tests/test_commit.py	2007-10-02 23:08:12 +0000
+++ tests/test_commit.py	2007-10-03 15:49:31 +0000
@@ -897,7 +897,7 @@
         dlg._do_commit()
 
         rev = tree.branch.repository.get_revision(dlg.committed_revision_id)
-        file_info = rev.properties['file-info']
+        file_info = rev.properties['file-info'].encode('UTF-8')
         value = ('ld7:file_id4:a-id'
                    '7:message16:Test \xc3\xban\xc3\xacc\xc3\xb6de\n'
                    '4:path1:a'
@@ -907,14 +907,11 @@
                    '4:path2:\xce\xa9'
                   'e'
                  'e')
-        self.expectFailure('bencode and unicode does not mix properly with'
-                           ' Revision XML serialization.',
-                           self.assertEqual, value, file_info)
         self.assertEqual(value, file_info)
         file_info_decoded = bencode.bdecode(file_info)
         for d in file_info_decoded:
-            d['path'] = d['path'].decode('utf8')
-            d['message'] = d['message'].decode('utf8')
+            d['path'] = d['path'].decode('UTF-8')
+            d['message'] = d['message'].decode('UTF-8')
 
         self.assertEqual([{'path':u'a', 'file_id':'a-id',
                            'message':u'Test \xfan\xecc\xf6de\n'},

